@@ -2,10 +2,7 @@
 #define APPEND_LIST_H
 
 #include "struct_VList.h"
-#include "xmalloc.h" // inline
-
-static VList *now;
-static VList *before_last;
+#include "xmalloc.h"
 
 /* 関数プロトタイプ */
 static inline VList * append_list(const void *tmp, VList *first);
@@ -15,6 +12,9 @@ static inline VList * append_list(const void *tmp, VList *first);
 *******************************************************************************/
 static inline VList * append_list(const void *tmp, VList *first)
 {
+	VList *now;
+	VList *before_last;
+
 	if(first == NULL)
 	{
 		/* リストに最初の要素を追加する */
