@@ -3,12 +3,14 @@
 
 #define _GNU_SOURCE
 
+#include "ch_time_and_mod_global.h"
 #include "print_error.h"
 #include "struct_CPInfo.h"
 
-#include <unistd.h>
 #include <fcntl.h>
+#include <linux/capability.h>
 #include <sys/stat.h>
+#include <unistd.h>
 
 /* 関数プロトタイプ */
 static inline void ch_time_and_mod(const int *idst, const struct stat *stat_buf, const CPInfo *cpinfo, CPDD *cpdd);
@@ -17,36 +19,37 @@ static inline void ch_time_and_mod(const int *idst, const struct stat *stat_buf,
 *******************************************************************************/
 static inline void ch_time_and_mod(const int *idst, const struct stat *stat_buf, const CPInfo *cpinfo, CPDD *cpdd)
 {
-	struct timespec time_s[2];
-
 	errno = 0;
 	if(fchmod(*idst, stat_buf->st_mode) == -1)
 	{
 		print_error("chmod", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "ファイル情報変更エラーです (%s) \n", cpinfo->dst);
+		fprintf(stderr, "error : %s\n", cpinfo->dst);
 	}
-/*
-	if(fchown(*idst, stat_buf->st_uid, stat_buf->st_gid) == -1)
-	{
-		print_error("chown", __FILE__, __LINE__, cpdd);
-	}
-*/
 
-	fchown(*idst, stat_buf->st_uid, stat_buf->st_gid);
+	/* 管理者権限がある場合のみchownする */
+	if(ut == CAP_CHOWN)
+	{
+		errno = 0;
+		if(fchown(*idst, stat_buf->st_uid, stat_buf->st_gid) == -1)
+		{
+			print_error("chown", __FILE__, __LINE__, cpdd);
+			fprintf(stderr, "error : %s\n", cpinfo->dst);
+		}
+	}
+
+	struct timespec time_s[2];
 
 	time_s[0].tv_sec = stat_buf->st_atime;
 	time_s[1].tv_sec = stat_buf->st_mtime;
 
 	time_s[0].tv_nsec = stat_buf->st_atim.tv_nsec;
-/* time_s[0].tv_nsec = stat_buf->st_atimensec; */
 	time_s[1].tv_nsec = stat_buf->st_mtim.tv_nsec;
-/* time_s[1].tv_nsec = stat_buf->st_mtimensec; */
 
 	/* 第四引数は0 or AT_SYMLINK_NOFOLLOW */
 	if(utimensat(AT_FDCWD, cpinfo->dst, time_s, AT_SYMLINK_NOFOLLOW) == -1)
 	{
 		print_error("utimensat", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "ファイル情報変更エラーです (%s) \n", cpinfo->dst);
+		fprintf(stderr, "error : %s\n", cpinfo->dst);
 	}
 }
 
