@@ -1,6 +1,7 @@
 #define _GNU_SOURCE
 
 #include "append_list.h"
+#include "ch_time_and_mod_dir.h"
 #include "compare_verify_one.h"
 #include "create_symboliclink.h"
 #include "print_error.h"
@@ -23,8 +24,6 @@
 
 #include <glib.h>
 #include <linux/limits.h>
-#include <sys/stat.h>
-#include <utime.h>
 
 /* 関数プロトタイプ */
 RData * check_target(const OPArg *, const VList *drive_list, const SDir *);
@@ -42,7 +41,6 @@ static inline char * get_dst_plus_srcname(const char *src, const char *dst);
 static inline void count_plus_link(CPInfo *, CPDD *);
 static inline void count_plus_file(CPInfo *, CPDD *);
 static inline void count_plus_dir(CPInfo *, CPDD *);
-static inline void ch_time_and_mod_dir(const CPInfo *, const struct stat *, CPDD *);
 static inline void clean(const char buf[], const int len);
 static inline void fgets_is_null(void);
 static inline void set_same_or_different(const VList *drive_list, const char *src, const char *dst, const OPArg *, CPInfo *);
@@ -134,7 +132,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 					if((errno != EEXIST) && (errno != 0))
 					{
 						print_error("mkdir", __FILE__, __LINE__, cpdd);
-						fprintf(stderr, "コピー先フォルダの作成に失敗しました\n");
+						fprintf(stderr, "error : %s\n", oparg->argv[loop_dst]);
 						exit(EXIT_FAILURE);
 					}
 				}
@@ -177,7 +175,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 		if(errno != 0)
 		{
 			print_error("realpath", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, "コピー先が不定です\n");
+			fprintf(stderr, "error : %s\n", oparg->argv[loop_dst]);
 			exit(EXIT_FAILURE);
 		}
 
@@ -186,7 +184,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 	else
 	{
 		print_error("realpath", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "コピー先が不定です\n");
+		fprintf(stderr, "error : %s\n", oparg->argv[loop_dst]);
 		exit(EXIT_FAILURE);
 	}
 
@@ -202,7 +200,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 		/* strcmpは等しければ0を返す */
 		if(strcmp(oparg->argv[loop], "..") == 0)
 		{
-			fprintf(stderr, "`..' をスキップします\n");
+			fprintf(stderr, "skip : ..\n");
 			continue;
 		}
 		else if(strcmp(oparg->argv[loop], ".") == 0)
@@ -230,7 +228,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 			if(errno != 0)
 			{
 				print_error("realpath", __FILE__, __LINE__, cpdd);
-				fprintf(stderr, "`%s'\n", oparg->argv[loop]);
+				fprintf(stderr, "error : %s\n", oparg->argv[loop]);
 				continue;
 			}
 		}
@@ -241,7 +239,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 		CPInfo *cpinfo = malloc_cpinfo();
 
 		len_src++;
-		cpinfo->src = xmalloc_inline(len_src);
+		cpinfo->src = xmalloc(len_src);
 		memcpy(cpinfo->src, tmp_src, len_src);
 		len_src--;
 
@@ -303,7 +301,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 				}
 				else
 				{
-					fprintf(stderr, "`%s' をスキップします\n", tmp_src);
+					fprintf(stderr, "skip : %s\n", tmp_src);
 				}
 			}
 			else
@@ -322,7 +320,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 					if((errno != EEXIST) && (errno != 0))
 					{
 						print_error("mkdir", __FILE__, __LINE__, cpdd);
-						fprintf(stderr, "コピー先フォルダの作成に失敗しました\n");
+						fprintf(stderr, "error : %s\n", oparg->argv[loop_dst]);
 						exit(EXIT_FAILURE);
 					}
 				}
@@ -354,7 +352,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 			}
 			else
 			{
-				fprintf(stderr, "`%s' をスキップします\n", tmp_src);
+				fprintf(stderr, "skip : %s\n", tmp_src);
 			}
 			break;
 		}
@@ -401,11 +399,11 @@ static inline VList * copy_arg_dir(const char *tmp_src, const char *tmp_dst, con
 	{
 		if(is_src_current == true)
 		{
-			fprintf(stderr, "`.' をスキップします\n");
+			fprintf(stderr, "skip : .\n");
 		}
 		else
 		{
-			fprintf(stderr, "`%s' をスキップします\n", cpinfo->src);
+			fprintf(stderr, "skip : %s\n", cpinfo->src);
 		}
 
 		if(cpinfo->src != NULL) free(cpinfo->src);
@@ -514,7 +512,7 @@ INPUT:
 			switch(iowt)
 			{
 			case INFO:
-				printf("overwrite ? `%s'\n", cpinfo->dst);
+				printf("overwrite? : %s\n", cpinfo->dst);
 				printf("y: Yes,  a: Yes (All),");
 
 				if(type == 'd')
@@ -740,14 +738,14 @@ static inline struct stat * make_directory(const OPArg *oparg, CPInfo *cpinfo, C
 		if((errno != EEXIST) && (errno != 0))
 		{
 			print_error("mkdir", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, "フォルダの作成に失敗しました (%s) \n", cpinfo->dst);
+			fprintf(stderr, "error : %s\n", cpinfo->dst);
 		}
 	}
 	else
 	{
 		if(oparg->V == VERBOS)
 		{
-			printf("`%s' -> `%s'\n", cpinfo->src, cpinfo->dst);
+			printf("%s -> %s\n", cpinfo->src, cpinfo->dst);
 			fflush(stdout);
 		}
 
@@ -764,7 +762,7 @@ static inline struct stat * make_directory(const OPArg *oparg, CPInfo *cpinfo, C
 	if(stat(cpinfo->src, stat_buf) != 0)
 	{
 		print_error("stat", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "フォルダ情報取得エラーです (%s) \n", cpinfo->src);
+		fprintf(stderr, "error : %s\n", cpinfo->src);
 		free(stat_buf);
 		stat_buf = NULL;
 	}
@@ -871,7 +869,7 @@ static VList * dir_traverse(const OPArg *oparg, const SDir *sdir, VList *file_li
 					}
 					else
 					{
-						fprintf(stderr, "このファイル (%s) をスキップします\n", cpinfo->src);
+						fprintf(stderr, "skip : %s\n", cpinfo->src);
 					}
 					break;
 				}
@@ -881,12 +879,13 @@ static VList * dir_traverse(const OPArg *oparg, const SDir *sdir, VList *file_li
 		if(closedir(dp) == -1)
 		{
 			print_error("closedir", __FILE__, __LINE__, cpdd);
+			fprintf(stderr, "error : %s\n", src_dir);
 		}
 	}
 	else
 	{
 		print_error("opendir", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "`%s' を読み取れませんでした\n", src_dir);
+		fprintf(stderr, "error : %s\n", src_dir);
 	}
 
 	/* フォルダ削除用 */
@@ -917,7 +916,7 @@ static inline void delete_last_slash(const int len, char tmp[])
 *******************************************************************************/
 static inline CPInfo * malloc_cpinfo(void)
 {
-	CPInfo *cpinfo = xmalloc_inline(sizeof(CPInfo));
+	CPInfo *cpinfo = xmalloc(sizeof(CPInfo));
 	cpinfo->src = NULL;
 	cpinfo->dst = NULL;
 	cpinfo->dstfs = NULL;
@@ -1040,43 +1039,6 @@ static inline void count_plus_dir(CPInfo *cpinfo, CPDD *cpdd)
 	}
 }
 
-/*******************************************************************************
-*******************************************************************************/
-static inline void ch_time_and_mod_dir(const CPInfo *cpinfo, const struct stat *stat_buf, CPDD *cpdd)
-{
-	errno = 0;
-
-	if(chmod(cpinfo->dst, stat_buf->st_mode) == -1)
-	{
-		print_error("chmod", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "error : %s\n", cpinfo->dst);
-	}
-
-/*
-	if(chown(cpinfo->dst, stat_buf->st_uid, stat_buf->st_gid) == -1)
-	{
-		print_error("chown", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "フォルダ情報変更エラーです (%s) \n", cpinfo->dst);
-	}
-*/
-
-	chown(cpinfo->dst, stat_buf->st_uid, stat_buf->st_gid);
-
-	struct timespec time_s[2];
-	time_s[0].tv_sec = stat_buf->st_atime;
-	time_s[1].tv_sec = stat_buf->st_mtime;
-
-	time_s[0].tv_nsec = stat_buf->st_atim.tv_nsec;
-	time_s[1].tv_nsec = stat_buf->st_mtim.tv_nsec;
-
-	/* 第四引数は0かAT_SYMLINK_NOFOLLOW */
-	if(utimensat(AT_FDCWD, cpinfo->dst, time_s, AT_SYMLINK_NOFOLLOW) == -1)
-	{
-		print_error("utimensat", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "error : %s\n", cpinfo->dst);
-	}
-}
-
 /*******************************************************************************
  * 入力バッファのクリア
 *******************************************************************************/
