@@ -14,8 +14,7 @@
 
 #define UNLINK_ERR \
 	print_error("unlink", __FILE__, __LINE__, cpdd);\
-	fprintf(stderr, "対象を削除出来ませんでした (%s) \n", cpinfo->dst);\
-	fprintf(stderr, "シンボリックリンクを作成できません\n");\
+	fprintf(stderr, "error : %s\n", cpinfo->dst);\
 	cpinfo->dst_para = INITIAL;
 
 /* 関数プロトタイプ */
@@ -62,7 +61,7 @@ static void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 			{
 				check = false;
 				print_error("lstat", __FILE__, __LINE__, cpdd);
-				fprintf(stderr, "ファイル情報取得エラーです (%s) \n", cpinfo->src);
+				fprintf(stderr, "error : %s\n", cpinfo->src);
 			}
 			else if(lstat(cpinfo->dst, &stat_dst) == -1)
 			{
@@ -74,7 +73,7 @@ static void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 				{
 					check = false;
 					print_error("lstat", __FILE__, __LINE__, cpdd);
-					fprintf(stderr, "ファイル情報取得エラーです (%s) \n", cpinfo->dst);
+					fprintf(stderr, "error : %s\n", cpinfo->dst);
 				}
 			}
 			else
@@ -121,8 +120,8 @@ static void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 
 				default:
 					check = false;
-					print_error("NODATA", __FILE__, __LINE__, cpdd);
-					fprintf(stderr, "上書きモードオプションエラーです (%s) \n", cpinfo->src);
+					print_error("NULL", __FILE__, __LINE__, cpdd);
+					fprintf(stderr, "option error : %s\n", cpinfo->src);
 					break;
 				}
 			}
@@ -130,7 +129,7 @@ static void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 	}
 	else
 	{
-		printf("`%s' をスキップします\n", cpinfo->dst);
+		printf("skip : %s\n", cpinfo->dst);
 		fflush(stdout);
 		check = false;
 	}
@@ -153,7 +152,7 @@ static _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd)
 	{
 		check = false;
 		print_error("readlink", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "シンボリックリンク読み込みエラーです (%s) \n", cpinfo->src);
+		fprintf(stderr, "error : %s\n", cpinfo->src);
 	}
 	else
 	{
@@ -175,7 +174,7 @@ static _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd)
 		{
 			check = false;
 			print_error("symlink", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, "シンボリックリンク作成エラーです (%s) \n", cpinfo->dst);
+			fprintf(stderr, "error : %s\n", cpinfo->dst);
 		}
 		else
 		{
@@ -188,7 +187,7 @@ static _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd)
 
 			if(oparg->V == VERBOS)
 			{
-				printf("`%s' -> `%s'\n", cpinfo->src, cpinfo->dst);
+				printf("%s -> %s\n", cpinfo->src, cpinfo->dst);
 				fflush(stdout);
 			}
 
@@ -197,7 +196,7 @@ static _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd)
 			if(lstat(cpinfo->src, &stat_buf) == -1)
 			{
 				print_error("lstat", __FILE__, __LINE__, cpdd);
-				fprintf(stderr, "ファイル情報取得エラーです (%s) \n", cpinfo->src);
+				fprintf(stderr, "error : %s\n", cpinfo->src);
 			}
 			else
 			{
