@@ -8,15 +8,15 @@
 
 #include <errno.h>
 
-static void print_error(const char *func, const char *file, const int line, CPDD *cpdd);
+static void print_error(const char *func, const char *source_file, const int line, CPDD *cpdd);
 
 /*******************************************************************************
 *******************************************************************************/
-static void print_error(const char *func, const char *file, const int line, CPDD *cpdd)
+static void print_error(const char *func, const char *source_file, const int line, CPDD *cpdd)
 {
-	printf("%s : %d行\n", file, line);
+	printf("%s : %d行\n", source_file, line);
 
-	if(strcmp(func, "NODATA") != 0)
+	if(strcmp(func, "NULL") != 0)
 	{
 		perror(func);
 	}
