@@ -13,23 +13,6 @@
 #define INPUT_LEN 256
 #define DEFAULT_BUFFER 32 * 1024 * 1024
 
-#define SET_HASH_CHECK_MODE \
-{\
-	if(buf[2] == '1')\
-	{\
-		oparg->CHECK_MODE = BEFORE;\
-	}\
-	else if(buf[2] == '2')\
-	{\
-		oparg->CHECK_MODE = AFTER;\
-	}\
-	else \
-	{\
-		fprintf(stderr, "設定ファイルが正しくありません\n");\
-		exit(EXIT_FAILURE);\
-	}\
-}
-
 /* 関数プロトタイプ */
 OPArg * read_conf(const SDir *sdir);
 
@@ -145,7 +128,20 @@ OPArg * read_conf(const SDir *sdir)
 					/* ベリファイ（MD5） */
 					case 'r':
 						oparg->CHECK = V_FIVE;
-						SET_HASH_CHECK_MODE
+
+						if(buf[2] == '1')
+						{
+							oparg->CHECK_MODE = BEFORE;
+						}
+						else if(buf[2] == '2')
+						{
+							oparg->CHECK_MODE = AFTER;
+						}
+						else
+						{
+							fprintf(stderr, "設定ファイルが正しくありません\n");
+							exit(EXIT_FAILURE);
+						}
 						break;
 					/* スレッドモード */
 					case 't':
