@@ -51,6 +51,7 @@
 	{\
 		is_direct_io = false;\
 		print_error("open", __FILE__, __LINE__, cpdd);\
+		fprintf(stderr, "error : %s\n", cpinfo->dst);\
 	}\
 	else \
 	{\
@@ -201,7 +202,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 	{
 		if(strcmp(cpinfo->src, cpinfo->dst) == 0)
 		{
-			fprintf(stderr, "`%s' と `%s' は同じファイルです\n", cpinfo->src, cpinfo->dst);
+			fprintf(stderr, "%s と %s は同じファイルです\n", cpinfo->src, cpinfo->dst);
 			return;
 		}
 	}
@@ -217,6 +218,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 			if((isrc = open(cpinfo->src, O_RDONLY | O_NOFOLLOW)) == -1)
 			{
 				print_error("open", __FILE__, __LINE__, cpdd);
+				fprintf(stderr, "error : %s\n", cpinfo->src);
 			}
 			else
 			{
@@ -226,6 +228,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 
 		default:
 			print_error("open", __FILE__, __LINE__, cpdd);
+			fprintf(stderr, "error : %s\n", cpinfo->src);
 			break;
 		}
 	}
@@ -242,6 +245,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 		if(fstat(isrc, &stat_buf) == -1)
 		{
 			print_error("fstat", __FILE__, __LINE__, cpdd);
+			fprintf(stderr, "error : %s\n", cpinfo->src);
 		}
 		else
 		{
@@ -266,6 +270,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 			if(stat(cpinfo->dst, &stat_dst) == -1)
 			{
 				print_error("stat", __FILE__, __LINE__, cpdd);
+				fprintf(stderr, "error : %s\n", cpinfo->dst);
 
 				if(errno == ENOENT)
 				{
@@ -298,11 +303,6 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 				}
 			}
 		}
-		else
-		{
-			print_error("NODATA", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, "`%s' をコピーできません\n", cpinfo->src);
-		}
 	}
 
 	/*
@@ -318,6 +318,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 		if(fallocate(idst, FALLOC_FL_KEEP_SIZE, 0, src_size_local) == -1)
 		{
 			print_error("fallocate", __FILE__, __LINE__, cpdd);
+			fprintf(stderr, "error : %s\n", cpinfo->dst);
 		}
 /*
 		static int itmp = -1;
@@ -347,7 +348,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 
 		if(oparg->V == VERBOS)
 		{
-			printf("`%s' -> `%s'\n", cpinfo->src, cpinfo->dst);
+			printf("%s -> %s\n", cpinfo->src, cpinfo->dst);
 			fflush(stdout);
 		}
 
@@ -391,6 +392,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 			if(ftruncate(idst, src_size_local) == -1)
 			{
 				print_error("ftruncate", __FILE__, __LINE__, cpdd);
+				fprintf(stderr, "error : %s\n", cpinfo->dst);
 			}
 		}
 	}
@@ -401,6 +403,7 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 		{
 			return_dst_ftruncate = -1;
 			print_error("ftruncate", __FILE__, __LINE__, cpdd);
+			fprintf(stderr, "error : %s\n", cpinfo->dst);
 		}
 
 		if(verify_option == true)
@@ -440,11 +443,13 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 	if((open_src == true) && (close(isrc) == -1))
 	{
 		print_error("close", __FILE__, __LINE__, cpdd);
+		fprintf(stderr, "error : %s\n", cpinfo->src);
 	}
 
 	if((open_dst == true) && (close(idst) == -1))
 	{
 		print_error("close", __FILE__, __LINE__, cpdd);
+		fprintf(stderr, "error : %s\n", cpinfo->dst);
 	}
 
 	write_now = NULL;
@@ -493,6 +498,7 @@ static inline void mw_small(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_
 	if(buf[0] == MAP_FAILED)
 	{
 		print_error("mmap", __FILE__, __LINE__, cpdd);
+		fprintf(stderr, "error : %s\n", cpinfo->src);
 	}
 	else
 	{
@@ -502,6 +508,7 @@ static inline void mw_small(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_
 		if(madvise(buf[0], src_size_local, MADV_WILLNEED) == -1)
 		{
 			print_error("madvise", __FILE__, __LINE__, cpdd);
+			fprintf(stderr, "error : %s\n", cpinfo->src);
 		}
 
 		if(verify_option == true)
@@ -522,6 +529,7 @@ static inline void mw_small(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_
 			if((written_size[0] = write(idst, tmp, endp - tmp)) == -1)
 			{
 				print_error("write", __FILE__, __LINE__, cpdd);
+				fprintf(stderr, "error : %s\n", cpinfo->dst);
 				break;
 			}
 
@@ -540,6 +548,7 @@ static inline void mw_small(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_
 		if(munmap(buf[0], src_size_local) != 0)
 		{
 			print_error("munmap", __FILE__, __LINE__, cpdd);
+			fprintf(stderr, "error : %s\n", cpinfo->src);
 		}
 	}
 }
@@ -584,6 +593,7 @@ static inline void mw_small_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *stat
 		if(buf[0] == MAP_FAILED)
 		{
 			print_error("mmap", __FILE__, __LINE__, cpdd);
+			fprintf(stderr, "error : %s\n", cpinfo->src);
 			break;
 		}
 		else
@@ -594,6 +604,7 @@ static inline void mw_small_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *stat
 			if(madvise(buf[0], read_size, MADV_WILLNEED) == -1)
 			{
 				print_error("madvise", __FILE__, __LINE__, cpdd);
+				fprintf(stderr, "error : %s\n", cpinfo->src);
 			}
 
 			if(verify_option == true)
@@ -611,6 +622,7 @@ static inline void mw_small_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *stat
 				if((written_size[0] = pwrite(idst, buf[0], write_size, total_write_local)) == -1)
 				{
 					print_error("write", __FILE__, __LINE__, cpdd);
+					fprintf(stderr, "error : %s\n", cpinfo->dst);
 					break;
 				}
 
@@ -621,6 +633,7 @@ static inline void mw_small_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *stat
 					if(lseek(idst, write_size, SEEK_CUR) == -1)
 					{
 						print_error("lseek", __FILE__, __LINE__, cpdd);
+						fprintf(stderr, "error : %s\n", cpinfo->dst);
 					}
 
 					break;
@@ -637,6 +650,7 @@ static inline void mw_small_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *stat
 			if(munmap(buf[0], read_size) != 0)
 			{
 				print_error("munmap", __FILE__, __LINE__, cpdd);
+				fprintf(stderr, "error : %s\n", cpinfo->src);
 			}
 		}
 	}
@@ -675,6 +689,7 @@ static inline void mw_big(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_by
 		if(buf[0] == MAP_FAILED)
 		{
 			print_error("mmap", __FILE__, __LINE__, cpdd);
+			fprintf(stderr, "error : %s\n", cpinfo->src);
 			break;
 		}
 		else
@@ -685,6 +700,7 @@ static inline void mw_big(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_by
 			if(madvise(buf[0], read_size, MADV_WILLNEED) == -1)
 			{
 				print_error("madvise", __FILE__, __LINE__, cpdd);
+				fprintf(stderr, "error : %s\n", cpinfo->src);
 			}
 
 			if(verify_option == true)
@@ -705,11 +721,13 @@ static inline void mw_big(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_by
 				if((written_size[0] = write(idst, tmp, endp - tmp)) == -1)
 				{
 					print_error("write", __FILE__, __LINE__, cpdd);
+					fprintf(stderr, "error : %s\n", cpinfo->dst);
 
 					errno = 0;
 					if(munmap(buf[0], read_size) != 0)
 					{
 						print_error("munmap", __FILE__, __LINE__, cpdd);
+						fprintf(stderr, "error : %s\n", cpinfo->src);
 					}
 
 					goto LOOP_END;
@@ -728,6 +746,7 @@ static inline void mw_big(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state, md5_by
 			if(munmap(buf[0], read_size) != 0)
 			{
 				print_error("munmap", __FILE__, __LINE__, cpdd);
+				fprintf(stderr, "error : %s\n", cpinfo->src);
 			}
 		}
 
@@ -794,6 +813,7 @@ static inline void mw_big_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state,
 		if(buf[0] == MAP_FAILED)
 		{
 			print_error("mmap", __FILE__, __LINE__, cpdd);
+			fprintf(stderr, "error : %s\n", cpinfo->src);
 			break;
 		}
 		else
@@ -804,6 +824,7 @@ static inline void mw_big_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state,
 			if(madvise(buf[0], read_size, MADV_WILLNEED) == -1)
 			{
 				print_error("madvise", __FILE__, __LINE__, cpdd);
+				fprintf(stderr, "error : %s\n", cpinfo->src);
 			}
 
 			if(verify_option == true)
@@ -821,6 +842,7 @@ static inline void mw_big_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state,
 				if((written_size[0] = pwrite(idst, buf[0], write_size, total_write_local)) == -1)
 				{
 					print_error("write", __FILE__, __LINE__, cpdd);
+					fprintf(stderr, "error : %s\n", cpinfo->dst);
 					break;
 				}
 
@@ -831,6 +853,7 @@ static inline void mw_big_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state,
 					if(lseek(idst, write_size, SEEK_CUR) == -1)
 					{
 						print_error("lseek", __FILE__, __LINE__, cpdd);
+						fprintf(stderr, "error : %s\n", cpinfo->dst);
 					}
 
 					break;
@@ -846,6 +869,7 @@ static inline void mw_big_direct(CPInfo *cpinfo, CPDD *cpdd, md5_state_t *state,
 			if(munmap(buf[0], read_size) != 0)
 			{
 				print_error("munmap", __FILE__, __LINE__, cpdd);
+				fprintf(stderr, "error : %s\n", cpinfo->src);
 			}
 		}
 	}
@@ -936,6 +960,7 @@ static inline void mw_thread(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, md5
 				if((written_size[wi] = write(idst, tmp, endp - tmp)) == -1)
 				{
 					print_error("write", __FILE__, __LINE__, cpdd);
+					fprintf(stderr, "error : %s\n", cpinfo->dst);
 					total_write_error++;
 					break;
 				}
@@ -960,6 +985,7 @@ static inline void mw_thread(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd, md5
 			if(munmap(buf[wi], next_write_size[wi]) == -1)
 			{
 				print_error("munmap", __FILE__, __LINE__, cpdd);
+				fprintf(stderr, "error : %s\n", cpinfo->src);
 				total_write_error++;
 			}
 		}
@@ -1030,6 +1056,7 @@ static inline void mw_thread_direct(const OPArg *oparg, CPInfo *cpinfo, CPDD *cp
 				if(written_size[wi] == -1)
 				{
 					print_error("write", __FILE__, __LINE__, cpdd);
+					fprintf(stderr, "error : %s\n", cpinfo->dst);
 					total_write_error++;
 					break;
 				}
@@ -1041,6 +1068,7 @@ static inline void mw_thread_direct(const OPArg *oparg, CPInfo *cpinfo, CPDD *cp
 					if(lseek(idst, total_write_local + written_size[wi], SEEK_SET) == -1)
 					{
 						print_error("write", __FILE__, __LINE__, cpdd);
+						fprintf(stderr, "error : %s\n", cpinfo->dst);
 						total_write_error++;
 						break;
 					}
@@ -1063,6 +1091,7 @@ static inline void mw_thread_direct(const OPArg *oparg, CPInfo *cpinfo, CPDD *cp
 			if(munmap(buf[wi], next_write_size[wi]) == -1)
 			{
 				print_error("munmap", __FILE__, __LINE__, cpdd);
+				fprintf(stderr, "error : %s\n", cpinfo->src);
 				total_write_error++;
 			}
 		}
@@ -1149,11 +1178,8 @@ static void * read_thread_func(void *unknown)
 static void * do_md5_append(void *tmp)
 {
 	struct verify_data *tmp_vd = tmp;
-	md5_state_t *state = tmp_vd->state;
-	md5_byte_t *buffer = tmp_vd->buffer;
-	int len = tmp_vd->len;
 
-	md5_append(state, buffer, len);
+	md5_append(tmp_vd->state, tmp_vd->buffer, tmp_vd->len);
 
 	return NULL;
 }
