@@ -13,7 +13,7 @@
 			if(errno != ENOENT)\
 			{\
 				print_error("unlink", __FILE__, __LINE__, cpdd);\
-				fprintf(stderr, "`%s' の削除に失敗しました\n", cpinfo->src);\
+				fprintf(stderr, "error : %s\n", cpinfo->src);\
 			}\
 		}\
 		else \
