@@ -1,5 +1,6 @@
 #include "analyze_argument.h"
 #include "check_target.h"
+#include "ch_time_and_mod_global.h"
 #include "compare_verify_two.h"
 #include "get_drive_list.h"
 #include "get_settings_dir.h"
@@ -69,6 +70,7 @@ int main(int argc, char **argv)
 	analyze_argument(argc, argv, oparg);
 	VList *drive_list = get_drive_list();
 	set_signal();
+	ut = geteuid();
 
 	puts("コピーを開始します...");
 	fflush(stdout);
