@@ -95,6 +95,7 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 	if((is_open == true) && (close(fd) == -1))
 	{
 		print_error("close", __FILE__, __LINE__, cpdd);
+		fprintf(stderr, "error : %s\n", cpinfo->dst);
 	}
 /*
 	free(buf[0]);
@@ -106,16 +107,16 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 *******************************************************************************/
 static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd)
 {
-	static _Bool get_memory = false;
+	static _Bool is_get_memory = false;
 
 	if((buf[0] == NULL) && (buf[1] == NULL))
 	{
 		if((posix_memalign((void **)&buf[0], psize, buffer_size_local) != 0) || (posix_memalign((void **)&buf[1], psize, buffer_size_local) != 0))
 		{
-			fprintf(stderr, "ベリファイに失敗しました\n");
-			fprintf(stderr, "`%s'\n", cpinfo->dst);
 			print_error("posix_memalign", __FILE__, __LINE__, cpdd);
+			fprintf(stderr, "verify error : %s\n", cpinfo->dst);
 			write_log_hash_check(cpinfo, oparg, cpinfo->src_md5, "NULL", sdir, cpdd, false);
+			cpinfo->dst_para = INITIAL;
 
 			if(buf[0] != NULL)
 			{
@@ -131,13 +132,12 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 		}
 		else
 		{
-			get_memory = true;
+			is_get_memory = true;
 		}
 	}
 
-	switch(get_memory)
+	if(is_get_memory == true)
 	{
-	case true:
 		md5_init(&state);
 
 		r_number = 0;
@@ -179,7 +179,7 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 			sprintf(hex_output + di * 2, "%02x", digest[di]);
 		}
 
-		_Bool unlink_miss_file = false;
+		_Bool is_equal = true;
 
 		if(strcmp(cpinfo->src_md5, hex_output) == 0)
 		{
@@ -203,39 +203,36 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 		}
 		else if(cpinfo->src_size > total)
 		{
-			unlink_miss_file = true;
-			fprintf(stderr, "ファイルの読み込みに失敗しました\n");
+			is_equal = false;
+			fprintf(stderr, "read error : %s\n", cpinfo->dst);
 		}
 		else
 		{
-			unlink_miss_file = true;
-			fprintf(stderr, "ハッシュ値が一致しませんでした\n");
+			is_equal = false;
+			fprintf(stderr, "hash error : %s\n", cpinfo->dst);
 		}
 
-		if(unlink_miss_file == true)
+		if(is_equal == false)
 		{
-			print_error("NODATA", __FILE__, __LINE__, cpdd);
+			print_error("NULL", __FILE__, __LINE__, cpdd);
+			fprintf(stderr, "verify error : %s\n", cpinfo->dst);
 			write_log_hash_check(cpinfo, oparg, cpinfo->src_md5, hex_output, sdir, cpdd, false);
 			cpinfo->dst_para = DELETE;
-			fprintf(stderr, "`%s' を削除します\n", cpinfo->dst);
 
 			errno = 0;
-			if((unlink(cpinfo->dst) == -1) && (errno != ENOENT))
+			if(unlink(cpinfo->dst) == -1)
 			{
-				print_error("unlink", __FILE__, __LINE__, cpdd);
-				fprintf(stderr, "`%s' の削除に失敗しました\n", cpinfo->dst);
+				if(errno != ENOENT)
+				{
+					print_error("unlink", __FILE__, __LINE__, cpdd);
+					fprintf(stderr, "error : %s\n", cpinfo->dst);
+				}
+			}
+			else
+			{
+				fprintf(stderr, "remove : %s\n", cpinfo->dst);
 			}
 		}
-
-		break;
-
-	case false:
-		fprintf(stderr, "ベリファイ出来ません\n");
-		fprintf(stderr, "メモリの確保に失敗しました\n");
-		print_error("NODATA", __FILE__, __LINE__, cpdd);
-		write_log_hash_check(cpinfo, oparg, cpinfo->src_md5, "NULL", sdir, cpdd, false);
-		cpinfo->dst_para = INITIAL;
-		break;
 	}
 }
 
