@@ -112,34 +112,40 @@ void verify_md5sum(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *c
 			}
 			else
 			{
-				fprintf(stderr, "ハッシュ値が一致しませんでした\n");
-				fprintf(stderr, "`%s' を削除します\n", cpinfo->dst);
-				print_error("NODATA", __FILE__, __LINE__, cpdd);
+				print_error("NULL", __FILE__, __LINE__, cpdd);
+				fprintf(stderr, "verify error : %s\n", cpinfo->dst);
 				write_log_hash_check(cpinfo, oparg, cpinfo->src_md5, ddst, sdir, cpdd, false);
 				cpinfo->dst_para = DELETE;
 
 				errno = 0;
-				if((unlink(cpinfo->dst) == -1) && (errno != ENOENT))
+				if(unlink(cpinfo->dst) == -1)
 				{
-					print_error("unlink", __FILE__, __LINE__, cpdd);
-					fprintf(stderr, "`%s' の削除に失敗しました\n", cpinfo->dst);
+					if(errno != ENOENT)
+					{
+						print_error("unlink", __FILE__, __LINE__, cpdd);
+						fprintf(stderr, "error : %s\n", cpinfo->dst);
+					}
+				}
+				else
+				{
+					fprintf(stderr, "remove : %s\n", cpinfo->dst);
 				}
 			}
 		}
 		else
 		{
-			print_error("NODATA", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, "ベリファイに失敗しました\n");
-			fprintf(stderr, "`%s'\n", cpinfo->dst);
+			print_error("NULL", __FILE__, __LINE__, cpdd);
+			fprintf(stderr, "verify error : %s\n", cpinfo->dst);
 			write_log_hash_check(cpinfo, oparg, "NULL", "NULL", sdir, cpdd, false);
+			cpinfo->dst_para = INITIAL;
 		}
 	}
 	else
 	{
-		print_error("NODATA", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "ベリファイに失敗しました\n");
-		fprintf(stderr, "`%s'\n", cpinfo->dst);
+		print_error("NULL", __FILE__, __LINE__, cpdd);
+		fprintf(stderr, "verify error : %s\n", cpinfo->dst);
 		write_log_hash_check(cpinfo, oparg, "NULL", "NULL", sdir, cpdd, false);
+		cpinfo->dst_para = INITIAL;
 	}
 
 	/* 念のため、pipe詰まり対策 */
